/*************************************************************/
/* File        : main.c                                      */
/* Author      : Paul Lemmens (paul.lemmens@student.kun.nl)  */
/*             : Dan Scott (dan.scott@acm.org)               */
/* Description : Defines the keyword-value struct            */
/* License     : GNU GPL                                     */
/*************************************************************/

/*
wmseti is a Windowmaker dockapp that displays seti@home client statistics.
Copyright (C) 2001 Paul Lemmens, Dan Scott

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <stdio.h>

#include "wmsetirc-file.h"
#include "cmdline.h"
#include "pixmap.h"
#include "dockapp.h"

/* These (boolean like) values are needed everywhere, so make them global. Watch out
 * for side effects though! */
int Version = 0;
int DebugLevel = 0;
int Verbose = 0;
int Help = 0;
int CmdlinedDir = 0;
int Afterstep = 0;
char ErrMsg[1024];

/************************************************************************************/
/* main initializes all necessary arrays and stuff. Prepares and sets the
 * eventhandler (needed to check the PID). Reads wmsetirc and commandline
 * (in that order, commandline overrides) and sets global values according to these
 * then starts an eternal loop doing the icon. Returns -1 upon failure and 0 upon
 * success (will never be reached however). */
/************************************************************************************/
int main(int argc, char **argv)
{
	wmsetirc_t rc;
	char buffer[128];
	pixmap_t pm;
	
	/* Initialize the struct after we've found a valid wmsetirc file,
	 * then read the file and set the global values accordingly (if needed). */
	if ( DebugLevel )
		fprintf(stderr, "\tLocating and parsing configurationfile\n");
	if ( find_wmsetirc(buffer) == NULL )
	{
		fprintf(stderr, "locating wmsetirc file in main()\n");
		return -1;
	}
	init_wmsetirc(&rc);
	if ( parse_wmsetirc(buffer, &rc) == -1 )
	{
		fprintf(stderr, "parsing %s in main()\n", buffer);
		return -1;
	}
	if ( DebugLevel >= 1 )
		fprintf(stderr, "\tConfigfile %s found and parsed\n", buffer);

	/* Now read the commandline, parse it and set global values 
	 * accordingly if necessary. After that take action.  */
	if ( DebugLevel >= 1 )
		fprintf(stderr, "\tParsing cmdline %s\n", argv[1]);
	if ( parse_cmdline(argc, argv, &rc) == -1 )
	{
		fprintf(stderr, "parsing the commandline in main()\n");
		return -1;
	}

	if ( DebugLevel >= 1 )
		fprintf(stderr, "\tIssuing help commands\n");
        if ( Help )
        {
                usage(argv);
                return -1;
        }
	else if ( Version )
        {
                printf("wmseti version %s, Copyright (C) 2001 Paul Lemmens, Dan Scott.\n", VERSION);
                printf("wmseti comes with ABSOLUTELY NO WARRANTY.\n");
                printf("This is free software, and you are welcome to redistribute\n");
                return -1;
        }
	else if ( Verbose )
	{
		print_wmsetirc(&rc);
	}

	/* Now start the routine for the dockapp, but not before we've prepared which
	 * pixmap we need. */
	if ( DebugLevel >= 1 )
	{
		fprintf(stderr, "\tPreparing pixmap for ");
		if ( Afterstep )
			fprintf(stderr, "Afterstep ");
		else
			fprintf(stderr, "default ");
		fprintf(stderr, " and starting dockapp\n");
	}
	if ( prep_pixmap(&pm) != 0 )
	{
		fprintf(stderr, "initializing the pixmap in main()\n");
		return -1;
	}
	if ( dockapp(&rc, &pm, argc, argv) != 0 )
	{
		fprintf(stderr, "starting the dockapp in main()\n");
		return -1;
	}

	return 0;
}
