/*************************************************************/
/* File        : pixmap.c                                    */
/* Author      : Paul Lemmens (paul.lemmens@student.kun.nl)  */
/* Description : Implements differences needed for afterstep */
/* License     : GNU GPL                                     */
/*************************************************************/

/*
wmseti is a Windowmaker dockapp that displays seti@home client statistics.
Copyright (C) 2000 Paul Lemmens

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <stdio.h>

#include "pixmap.h"
#include "global.h"

#include "wmseti-master.xpm"
#include "wmseti-afterstep.xpm"

/************************************************************************************/
/* prep_pixmap() prepares a pixmap struct by setting all values of the struct 
 * properly according to the afterstep commandline option. Defaults to master (i.e.,
 * non afterstep). Returns 0 upon success and -1 upon failure. */
/************************************************************************************/
int prep_pixmap(pixmap_t *pm)
{
	/* Afterstep is a global value indicating whether we want Afterstep or not. */
	if ( Afterstep )
	{
		if ( DebugLevel >= 3 )
			fprintf(stderr, "\t\t\tUsing Afterstep settings.\n");
		pm->pixmap = afterstep_xpm;
		pm->size = ASTEP_SIZE;
		pm->border = ASTEP_BORDER;
		pm->xo = ASTEP_XO;
		pm->yo = ASTEP_YO;
		pm->lc = ASTEP_LASTCHAR;
	}
	else
	{
		if ( DebugLevel >= 3 )
			fprintf(stderr, "\t\t\tUsing default settings.\n");
		pm->pixmap = wmseti_master_xpm;
		pm->size = MASTER_SIZE;
		pm->border = MASTER_BORDER;
		pm->xo = MASTER_XO;
		pm->yo = MASTER_YO;
		pm->lc = MASTER_LASTCHAR;
	}

	return 0;
}
