/*************************************************************/
/* File        : statistics.h                                */
/* Author      : Paul Lemmens (paul.lemmens@student.kun.nl)  */
/* Description : Implements structs etc. for reading stats   */
/* License     : GNU GPL                                     */
/*************************************************************/

/*
wmseti is a Windowmaker dockapp that displays seti@home client statistics.
Copyright (C) 2000 Paul Lemmens

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __statistics_h__
#define __statistics_h__

#include <sys/types.h>

#define USERINFO_FILE "user_info.sah"
#define STATE_FILE "state.sah"
#define PID_FILE "pid.sah"

#define TIME_LEN 9		/* 9 characters to display a time thingie. (incl. \0). */
#define PERCENT_LEN 7		/* 7 chars to display a percentage (incl. \0). */
#define WORKUNIT_KEYWORDS "cpu prog"
				/* Keywords that should be present in STATE_FILE. */
#define USERINFO_KEYWORDS "nwus nresults"
				/* Keywords that should be present in USERINFO_FILE. */

/***********************************************************************************/
/* The stats_t struct contains per directory information of the status of seti
 * client.
 * - pid contains the pid of the SETI@home client
 * - status contains a character describing the state of the SETI@home client
 * - progress contains the percentage done on a workunit
 * - cputime contains the time needed to complete progress
 * - timeleft contains (a calculated) time needed to complete the workunit
 * - nwus contains the number of units received
 * - nresults contains the number of units calculated. */
/***********************************************************************************/
typedef struct
{
	pid_t pid;
	char status[20];
	char progress[PERCENT_LEN];
	char cputime[TIME_LEN];
	char timeleft[TIME_LEN];
	int nwus;
	int nresults;
} stats_t;

/* Initializing stats_t to all empty or default values. */
stats_t *init_stats(stats_t *);

/* Get the PID of the client from the file pid.sah. */
pid_t get_pid(const char *);

/* Get the workunit specific data and put them in the struct already. */
stats_t *read_workunit_stats(const char *, stats_t *);

/* Get the user specific data and put the into the struct. */
stats_t *read_user_stats(const char *, stats_t *);

/* Combine everything and put it in the struct. */
stats_t *read_stats(stats_t *, const char *);

#endif /* __statistics_h__ */
