/*************************************************************/
/* File        : wmsetirc-file.h                             */
/* Author      : Paul Lemmens (paul.lemmens@student.kun.nl)  */
/* Description : Structs and stuff for reading wmsetirc      */
/* License     : GNU GPL                                     */
/*************************************************************/

/*
wmseti is a Windowmaker dockapp that displays seti@home client statistics.
Copyright (C) 2000 Paul Lemmens

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __wmsetirc_file_h__
#define __wmsetirc_file_h__

#define LEN_SETIDIR 150 	/* 150 characters for an expanded path */
#define NUM_SETIDIRS 10		/* 10 setidirs to check */
#define ICON_LINES 5		/* 5 lines in the dockapp icon */
#define LEN_STATS 10		/* 10 characters for each statistic name */
#define WMSETIRC_KEYWORDS "setidir title prog cpu nwus nresults pid timeleft flashpid"
				/* All valid keywords that can be used in wmsetirc */
#define WMSETIRC_SEQ_KEYWORDS "title prog cpu nwus nresults pid timeleft"
				/* All valid statistics that can be displayed */

/***********************************************************************************/
/* Struct containing all information in wmsetirc.
 *
 * - setidirs: array of NUM_SETIDIR dirs (strings of length LEN_SETIDIR) to monitor;
 * - numdirs: integer containing the next available index of setidirs[];
 * - currentdir: location of the directory currently under examination;
 * - currentdirnum: index in setidirs of currentdir;
 * - rcfile: location of the wmsetirc file;
 * - sequence: array containing the sequence of stats to display;
 * - pid: the pid of the current setidir (current_dir);
 * - flashpid: boolean indicating whether to flash the pid or not;
 * - signal: contains a signal for rechecken the pid. */
/***********************************************************************************/
typedef struct
{
	char setidirs[NUM_SETIDIRS][LEN_SETIDIR];
	int numdirs;
	char currentdir[LEN_SETIDIR];
	int currentdirnum;
	char rcfile[LEN_SETIDIR];
	char sequence[ICON_LINES][LEN_STATS];
	int pid;
	int flashpid;
	int signal;
} wmsetirc_t;

/* Initialize all values to defaults of wmseti. */
wmsetirc_t *init_wmsetirc(wmsetirc_t *);

/* Prototype for a functioning finding (any) wmsetirc file. */
char *find_wmsetirc(char *);

/* Prototype for the parsing function (of wmsetirc). */
int parse_wmsetirc(const char *, wmsetirc_t *);

/* Prototype for configuration printing for Verbose cmdline switch. */
void print_wmsetirc(wmsetirc_t *);

/* Insert a setidir on the next appropriate location in the array of directories. */
int insert_setidir(const char *, wmsetirc_t *);

/* Insert a statistic to be displayed into the sequence with its indicated number. */
int insert_stat(const char *, const int, wmsetirc_t *);

/* Prototype for fetching a certain directory out of setidirs. */
char *fetch_setidir(const int, const wmsetirc_t *, char *);

/* Fetch a certain line for the dockapp icon. */
char *fetch_sequence(const int, const wmsetirc_t *, char *);

/* Scrolls to the next available setidir in setidirs. */
int scrollsetidirs(wmsetirc_t *);

#endif /* __wmsetirc_file_h__ */
